;;****************************************************************************
;; FileName : WDLIB.ASM
;; Function : Control Watch Dog Time Out.
;; Design's : By Ray
;; BuildDate: Tue 11-18-2003 V1.1
;;****************************************************************************

;;Function declare as follows:
PUBLIC  EnWD            ;;enable watch dog
PUBLIC  TriggerWD       ;;Trigger watch dog
PUBLIC  DisWD           ;;disable watch dog

;;Default value define as follows:
equWdUnitS	=	00h     ;Watch dog counter value of unit is second
equWdUnitM	=	08h     ;Watch dog counter value of unit is minute
South_SMBus_Addr=	400h	;South_Chipset SMBus Base Address
Deviec_SMBus_Addr=	9ch	;Decive SMBus Base Address
SMBus_Host_Status=	00h	;occupy 1 byte
SMBus_Slave_Status=	01h	;occupy 1 byte
SMBus_Host_Control=	02h     ;occupy 1 byte
SMBus_Host_Command=	03h     ;occupy 1 byte
SMBus_Host_Address=	04h     ;occupy 1 byte
SMBus_Host_Data0=	05h     ;occupy 1 byte
LED_CR		=	20h	;LED Control Register, occupy 1 byte
WDTCR		=	25h	;WatchDog Timer Control Register, occupy 1 byte
WDTRR		=	26h	;WatchDog Timer Range Register, occupy 1 byte

        .model  small
        .code
        .286
WatchDogLib:
;;
;;==========================================================================
;; rw_f75101r_smbus                                                         
;;==========================================================================
;; Function : Read or write smbus for Fintek_F75101R
;; Enter    : AH -> 0: Write smbus
;; 	            1: Read smbus
;; 	      BL -> index register for Fintek_F75101R
;;	      BH -> write data into Fintek_F75101R data register
;; Return   : AL -> read data for Fintek_F75101R
;; Cnange   : AX, CX, DX, Flag
;;==========================================================================
rw_f75101r_smbus:
	mov	dx,South_SMBus_Addr+SMBus_Host_Status
	mov	al,0feh
	out	dx,al
	jmp	$+2
	nop
	nop
	in	al,dx
	test	al,01fh
	jnz	rw_f75101r_smbus
	
	mov	dx,South_SMBus_Addr+SMBus_Host_Command
	mov	al,bl
	out	dx,al
	jmp	$+2
	
	mov	dx,South_SMBus_Addr+SMBus_Host_Address
	mov	al,Deviec_SMBus_Addr
	add	al,ah
	out	dx,al
	jmp	$+2
	
	mov	dx,South_SMBus_Addr+SMBus_Host_Data0
	mov	al,bh
	out	dx,al
	jmp	$+2
	
	mov	dx,South_SMBus_Addr+SMBus_Host_Control
	mov	al,48h
	out	dx,al
	jmp	$+2
	
	nop
	mov	dx,South_SMBus_Addr+SMBus_Host_Data0
	in	al,dx
	
	mov	cx,60
	loop	$
	ret
;;
;;==========================================================================
;; EnWD                                                                     
;;==========================================================================
;; Function : Enable watch dog                                              
;; Enter    : CH = Watch dog counter value of unit		
;;                 00h : Second
;;		   08h : Minute                                              
;;            CL = watch dog time out of value                              
;; Return   : None                                                          
;; Change   : None                                                          
;;==========================================================================
EnWD:
TriggerWD:
        pusha
        
        push	cx
	mov	ah,0			;Disabled WDT
	mov	bl,WDTCR
	mov	bh,11h
	call	rw_f75101r_smbus
	pop	cx
	
        push	cx
	mov	ah,0			;Enabled WD LED
	mov	bl,LED_CR
	mov	bh,02h
	call	rw_f75101r_smbus
	pop	cx
	
	push	cx
	mov	ah,0			;Set WD Timer out
	mov	bl,WDTRR
	mov	bh,cl
	call	rw_f75101r_smbus
	pop	cx
	
        push	cx
	mov	ah,0			;Enabled WDT
	mov	bl,WDTCR
	mov	bh,31h
	or	bh,ch
	call	rw_f75101r_smbus
	pop	cx

        popa
        ret
;;
;;==========================================================================
;; DisWD                                                                    
;;==========================================================================
;; Function : Disable watch dog                                             
;; Enter    : None					    
;; Return   : None                                                          
;; Change   : None                                                          
;;==========================================================================
DisWD:
        pusha
        
	mov	ah,0			;Disabled WDT
	mov	bl,WDTCR
	mov	bh,11h
	call	rw_f75101r_smbus
	
	mov	ah,0			;Enabled WD LED
	mov	bl,LED_CR
	mov	bh,03h
	call	rw_f75101r_smbus
	
        popa
        ret
;;
;;==================== END ====================
        END     WatchDogLib
